@@ -10,11 +10,11 @@ Dancer2::Debugger - Dancer2 panels for Plack::Debugger
 
 =head1 VERSION
 
-0.003
+0.004
 
 =cut
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Dancer2::Core::Types;
 use File::Spec;
@@ -223,7 +223,13 @@ Defaults to C<< JSON::MaybeXS->new( convert_blessed => 1, utf8 => 1 ) >>
 has serializer => (
     is      => 'ro',
     isa     => Object,
-    default => sub { JSON::MaybeXS->new( convert_blessed => 1, utf8 => 1 ) },
+    default => sub {
+        JSON::MaybeXS->new(
+            convert_blessed => 1,
+            allow_blessed   => 1,
+            utf8            => 1
+        );
+    },
 );
 
 =head2 storage
